import { MagicalClass } from 'js-magic';
import { AxiosInstance } from 'axios';
import { IHttpRequestHandler, IRequestResponse } from './types/http-request-handler';
/**
 * Handles dispatching of API requests
 */
export declare class ApiHandler implements MagicalClass {
    /**
     * TS Index signature
     */
    [x: string]: any;
    /**
     * Api Url
     *
     * @memberof ApiHandler
     */
    apiUrl: string;
    /**
     * @var httpRequestHandler Request Wrapper Instance
     */
    httpRequestHandler: IHttpRequestHandler;
    /**
     * Endpoints
     *
     * @memberof ApiHandler
     */
    apiEndpoints: Record<string, any>;
    /**
     * Logger
     *
     * @memberof ApiHandler
     */
    logger: any;
    constructor({ apiUrl, apiEndpoints, strategy, logger, httpRequestErrorService, }: {
        apiUrl: any;
        apiEndpoints: any;
        strategy?: any;
        logger?: any;
        httpRequestErrorService?: any;
    });
    /**
     * Get Provider Instance
     *
     * @returns {AxiosInstance} Provider's instance
     * @memberof HttpRequestHandler
     */
    getInstance(): AxiosInstance;
    /**
     * Maps all API requests
     *
     * @param {*} prop          Caller
     * @returns {Function}      Tailored request function
     * @memberof ApiHandler
     */
    __get(prop: any): any;
    /**
     * Handle Single API Request
     *
     * @param {*} args      Arguments
     * @returns {Promise}   Resolvable API provider promise
     * @memberof ApiHandler
     */
    handleRequest(...args: any): Promise<IRequestResponse>;
    /**
     * Triggered when trying to use non-existent endpoints
     * @param prop Method Name
     */
    protected handleNonImplemented(prop: string): Promise<any>;
}
